/**
 * Copyright 2012 Scott Weeden-Moody
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.lillicoder.newsblurry;

import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;

import com.lillicoder.actionbarcompatplus.ActionBarActivity;
import com.lillicoder.newsblurry.feeds.FeedsActivity;
import com.lillicoder.newsblurry.login.LoginActivity;
import com.lillicoder.newsblurry.net.PreferenceCookieStore;

/**
 * Base activity for app activities. This base activity will
 * handle basic activity configuration, such as home screen interaction
 * and ActionBar setup.
 * @author lillicoder
 */
public abstract class BaseActivity extends ActionBarActivity {

	/**
	 * Home activity classes. These are used a convenience for simplifying app navigation. 
	 */
	private static final Class<FeedsActivity> HOME_ACTIVITY_LOGGED_IN = FeedsActivity.class;
	private static final Class<LoginActivity> HOME_ACTIVITY_DEFAULT = LoginActivity.class;

	/**
	 * Callback for establishing references to child views and fragments. 
	 * This is called directly after {@link #setContentView(int)}.
	 */
	protected abstract void onInitializeChildReferences();
	
	@Override
	protected void onPostCreate(Bundle savedInstanceState) {
		super.onPostCreate(savedInstanceState);
		
		// TODO Configure basic ActionBar state.
	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		MenuInflater inflater = this.getMenuInflater();
		inflater.inflate(R.menu.actionbar_menu, menu);
		
		return super.onCreateOptionsMenu(menu);
	}
	
	/**
	 * Gets the home activity {@link Class}.
	 * @return Home activity {@link Class}.
	 */
	private Class<?> getHomeActivity() {
		if (this.isSessionIdAvailable())
			return HOME_ACTIVITY_LOGGED_IN;
		else
			return HOME_ACTIVITY_DEFAULT;
	}

	/**
	 * Gets an {@link Intent} that launches the home activity.
	 * @return {@link Intent} configured to launch the home activity.
	 */
	protected Intent getHomeActivityIntent() {
		Class<?> homeActivity = this.getHomeActivity();
		return new Intent(this, homeActivity);
	}
	
	/**
	 * Determines if this activity is an instance of the home activity.
	 * @return <code>true</code> if this activity is an instance of the home activity
	 * 		   <code>false</code> otherwise.
	 */
	protected boolean isHomeActivity() {
		Class<?> homeActivity = this.getHomeActivity();
		return this.getClass().isAssignableFrom(homeActivity);
	}

	/**
	 * Determines if a user session ID is available.
	 * @return <code>true</code> if a user session ID is available,
	 * 		   <code>false</code> otherwise.
	 */
	private boolean isSessionIdAvailable() {
		PreferenceCookieStore cookieStore = new PreferenceCookieStore(this);
		return cookieStore.containsCookie("newsblur_sessionid");
	}

	@Override
	public void setContentView(int layoutResId) {
		super.setContentView(layoutResId);
		
		// Fire initialization callback.
		this.onInitializeChildReferences();
	}
	
}