/**
 * Copyright 2012 Scott Weeden-Moody
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.lillicoder.newsblurry.feeds;

import java.io.Serializable;
import java.util.List;

/**
 * Interface for feed classes. This unifies the type that
 * the feeds list will work with to avoid mixed
 * folder and feed listings in a feed folder.
 * @author lillicoder
 */
public interface IFeed extends Comparable<IFeed>, Serializable {

	/**
	 * Gets the child {@link IFeed} for this feed.
	 * @return {@link List} of child {@link IFeed}.
	 */
	public List<IFeed> getChildren();
	
	/**
	 * Gets the {@link Favicon} for this feed.
	 * @return Feed {@link Favicon}.
	 */
	public Favicon getFavicon();
	
	/**
	 * Gets the name of this feed.
	 * @return Feed name.
	 */
	public String getName();
	
	/**
	 * Gets the {@link UnreadCounts} of unread stories in this feed.
	 * @return Feed {@link UnreadCounts}.
	 */
	public UnreadCounts getUnreadCounts();
	
	/**
	 * Determines if this feed has child feeds or folders.
	 * @return <code>true</code> if this feed has children,
	 * 		   <code>false</code> otherwise.
	 */
	public boolean hasChildren();
	
}