/**
 * Copyright 2012 Scott Weeden-Moody
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.lillicoder.newsblurry.login;

/**
 * Model for the login response received from the login API endpoint.
 * @author lillicoder
 */
public class LoginResponse {

	private int _code;
	private boolean _isAuthenticated;
	private String _result;
	
	// TODO Provide a collection of error values here.
	
	/**
	 * Instantiates this instance with the given response code, authenticated value, and result text.
	 * @param responseCode Response code from the login request.
	 * @param isAuthenticated Authenticated value from the login request.
	 * @param result Result text from the login request.
	 */
	public LoginResponse(int responseCode, boolean isAuthenticated, String result) {
		this._code = responseCode;
		this._isAuthenticated = isAuthenticated;
		this._result = result;
	}
	
	/**
	 * Gets the response code for this login response.
	 * @return Response code.
	 */
	public int getReponseCode() {
		return this._code;
	}

	/**
	 * Gets the result text for this login response.
	 * @return Result text.
	 */
	public String getResultText() {
		return this._result;
	}
	
	/**
	 * Determines if this login response was successfully authenticated or not.
	 * @return <code>true</code> if this login was successfully authenticated,
	 * 		   <code>false</code> otherwise.
	 */
	public boolean isAuthenticated() {
		return this._isAuthenticated;
	}
	
}