/**
 * Copyright 2012 Scott Weeden-Moody
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.lillicoder.newsblurry.login;

import junit.framework.Assert;

import org.json.JSONException;
import org.json.JSONObject;

/**
 * Utility class that can parse {@link JSONObject} responses
 * to produce {@link LoginResponse} instances.
 * @author lillicoder
 */
public class LoginResponseParser {

	private static final String JSON_KEY_AUTHENTICATED = "authenticated";
	private static final String JSON_KEY_REPONSE_CODE = "code";
	private static final String JSON_KEY_RESULT_TEXT = "result";

	/**
	 * Parses a new {@link LoginResponse} from the given login response {@link JSONObject}.
	 * @param responseJson Login response {@link JSONObject} to parse.
	 * @return {@link LoginRespone} parsed from the given response JSON.
	 * @throws JSONException Thrown if the given response JSON does not match the expected format.
	 */
	public LoginResponse parseLoginResponse(JSONObject responseJson) throws JSONException {
		Assert.assertTrue(responseJson != null);
		
		// TODO add support for errors JSONArray parsing
		int responseCode = responseJson.getInt(JSON_KEY_REPONSE_CODE);
		boolean isAuthenticated = responseJson.getBoolean(JSON_KEY_AUTHENTICATED);
		String resultText = responseJson.getString(JSON_KEY_RESULT_TEXT);
		
		return new LoginResponse(responseCode, isAuthenticated, resultText);
	}
	
}