/**
 * Copyright 2012 Scott Weeden-Moody
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.lillicoder.newsblurry.net;

/**
 * Callback interface for use with
 * @author lillicoder
 *
 * @param <T> 
 */
public interface OnTaskCompletedListener<T> {

	/**
	 * Callback that occurs before associated task begins executing.
	 * This callback occurs on the UI thread.
	 */
	public void onPreExecute();
	
	/**
	 * Callback that occurs when the associated task fails its
	 * execution. This callback occurs on the UI thread.
	 * @param exception {@link Exception} generated by the associated task's failure.
	 */
	public void onFailure(Exception exception);
	
	/**
	 * Callback that occurs when the associated task successfully finishes
	 * its execution. This callback occurs on the UI thread.
	 * @param t {@link T} result generated by the associated task's success.
	 */
	public void onSuccess(T result);
	
}