/**
 * Copyright 2012 Scott Weeden-Moody
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.lillicoder.newsblurry.net;

import java.util.LinkedList;
import java.util.Queue;

/**
 * Singleton queue for {@link BaseRequest} instances.
 * @author lillicoder
 */
public class RequestQueue {

	private static RequestQueue sInstance;
	
	private Queue<BaseRequest> _requestQueue;
	
	/**
	 * Singleton constructor.
	 */
	private RequestQueue() {
		this.setRequestQueue(new LinkedList<BaseRequest>());
	}
	
	/**
	 * Gets the {@link RequestQueue} instance.
	 * @return The {@link RequestQueue} instance.
	 */
	public static RequestQueue getInstance() {
		if (sInstance == null)
			sInstance = new RequestQueue();
		
		return sInstance;
	}
	
	/**
	 * Queues the given {@link BaseRequest} for execution.
	 * The request will be executed at the next best available time
	 * based on the rules of this queue.
	 * @param request {@link BaseRequest} to queue.
	 */
	public void queueRequest(BaseRequest request) {
		Queue<BaseRequest> requestQueue = this.getRequestQueue();
		requestQueue.add(request);
	}
	
	/**
	 * Gets this queue's local request {@link Queue}.
	 * @return
	 */
	private Queue<BaseRequest> getRequestQueue() {
		return this._requestQueue;
	}
	
	/**
	 * Sets this queue's local request {@link Queue}.
	 * This is intended for instance construction.
	 * @param queue {@link Queue} to set.
	 */
	private void setRequestQueue(Queue<BaseRequest> queue) {
		this._requestQueue = queue;
	}
}