/**
 * Copyright 2012 Scott Weeden-Moody
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.lillicoder.newsblurry.stories;

import com.lillicoder.newsblurry.net.BaseRequest;

/**
 * Request that marks a story as read.
 * @author lillicoder
 */
public class MarkStoryAsReadRequest extends BaseRequest {

	private static final String EXCEPTION_INVALID_STORY_CONSTRUCTOR_PARAM = 
		"The given Story must not be null.";
	
	private Story _story;
	
	/**
	 * Instantiates this instance with the {@link Story} to mark as read.
	 * @param story {@link Story} to mark as read.
	 */
	public MarkStoryAsReadRequest(Story story) {
		if (story == null)
			throw new IllegalArgumentException(EXCEPTION_INVALID_STORY_CONSTRUCTOR_PARAM);
		
		this.setStory(story);
	}

	/**
	 * Gets this request's {@link Story}.
	 * @return Request {@link Story}.
	 */
	public Story getStory() {
		return this._story;
	}
	
	/**
	 * Sets this request's {@link Story}.
	 * @param story {@link Story} to set.
	 */
	private void setStory(Story story) {
		this._story = story;
	}

}