/**
 * Copyright 2012 Scott Weeden-Moody
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.lillicoder.newsblurry.stories;

import java.util.List;

import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;

/**
 * Adapter for use with {@link StoriesListFragment}.
 * @author lillicoder
 */
public class StoriesListAdapter extends BaseAdapter {

	private static final String EXCEPTION_NULL_STORY_DATA = "Backing data at position %d is null, cannot get view at this poition.";
	private List<Story> _stories;
	
	/**
	 * Instantiates a new adapter backed by the given collection of {@link Story}.
	 * @param stories Backing {@link List} of {@link Story}.
	 */
	public StoriesListAdapter(List<Story> stories) {
		this.setStoriesList(stories);
	}
	
	@Override
	public int getCount() {
		List<Story> stories = this.getStoriesList();
		
		if (stories != null)
			return stories.size();
		else
			return 0;
	}

	@Override
	public Story getItem(int position) {
		List<Story> stories = this.getStoriesList();
		
		if (stories != null)
			return stories.get(position);
		else
			return null;
	}

	@Override
	public long getItemId(int position) {
		return position;
	}

	@Override
	public View getView(int position, View convertView, ViewGroup parent) {
		if (convertView == null) {
			Context context = parent.getContext();
			convertView = new StoryListItemView(context);
		}
		
		Story story = this.getItem(position);
		if (story == null)
			throw new IllegalStateException(String.format(EXCEPTION_NULL_STORY_DATA, position));
		
		StoryListItemView itemView = (StoryListItemView) convertView;
		itemView.setStory(story);
		
		return convertView;
	}
	
	/**
	 * Gets this adapter's backing collection of {@link Story}.
	 * @return Backing {@link List} of {@link Story}.
	 */
	private List<Story> getStoriesList() {
		return this._stories;
	}
	
	/**
	 * Sets the collection of {@link Story} for this adapter.
	 * This is intended for instance construction, to update
	 * the adapter see {@link #updateStories(List)}.
	 * @param stories {@link List} of {@link Story} to set.
	 */
	private void setStoriesList(List<Story> stories) {
		this._stories = stories;
	}
	
	/**
	 * Updates this adapter with the given collection of {@link Story}.
	 * @param stories {@link List} of updated {@link Story}.
	 */
	public void update(List<Story> stories) {
		this.setStoriesList(stories);
		this.notifyDataSetChanged();
	}

}