/**
 * Copyright 2012 Scott Weeden-Moody
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.lillicoder.newsblurry.stories;

import java.io.Serializable;

/**
 * Model for a single story for a feed.
 * @author lillicoder
 */
public class Story implements Serializable {

	/**
	 * Serialization ID. 
	 */
	private static final long serialVersionUID = 7921439370878489192L;
	
	boolean _isRead;
	private String _id;
	private String _title;
	private String _permalink;
	private String _content;

	public Story(String id, String title, String permalink, String content, boolean isRead) {
		this.setId(id);
		this.setTitle(title);
		this.setPermalink(permalink);
		this.setContent(content);
		this.setIsRead(isRead);
	}
	
	/**
	 * Gets the content for this story.
	 * @return Story content.
	 */
	public String getContent() {
		return this._content;
	}

	/**
	 * Gets the ID for this story.
	 * @return Story ID.
	 */
	public String getId() {
		return this._id;
	}
	
	/**
	 * Gets the permalink for this story.
	 * @return Story permalink.
	 */
	public String getPermalink() {
		return this._permalink;
	}

	/**
	 * Gets the title for this story.
	 * @return Story title.
	 */
	public String getTitle() {
		return this._title;
	}

	/**
	 * Determines if this story has been read.
	 * @return <code>true</code> if this story has been read,
	 * 		   <code>false</code> otherwise.
	 */
	public boolean isRead() {
		return this._isRead;
	}
	
	/**
	 * Sets the content for this story.
	 * @param Story content to set.
	 */
	private void setContent(String content) {
		this._content = content;
	}
	
	/**
	 * Sets the ID for this story.
	 * @param Story ID to set.
	 */
	private void setId(String id) {
		this._id = id;
	}
	
	/**
	 * Sets this story as read or unread.
	 * @param isRead <code>true</code> to set story as read,
	 * 				 <code>false</code> to set story as unread.
	 */
	private void setIsRead(boolean isRead) {
		this._isRead = isRead;
	}

	/**
	 * Sets the permalink for this story.
	 * @param Story permalink to set.
	 */
	private void setPermalink(String permalink) {
		this._permalink = permalink;
	}

	/**
	 * Sets the title for this story.
	 * @param Story title to set.
	 */
	private void setTitle(String title) {
		this._title = title;
	}

}