/**
 * Copyright 2012 Scott Weeden-Moody
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.lillicoder.newsblurry.stories;

import junit.framework.Assert;
import android.content.Context;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.widget.FrameLayout;
import android.widget.TextView;

import com.lillicoder.newsblurry.R;

public class StoryListItemView extends FrameLayout {

	private TextView _title;
	
	public StoryListItemView(Context context) {
		this(context, null);
	}
	
	public StoryListItemView(Context context, AttributeSet attrs) {
		this(context, attrs, 0);
	}
	
	public StoryListItemView(Context context, AttributeSet attrs, int defStyle) {
		super(context, attrs, defStyle);
		
		LayoutInflater inflater = LayoutInflater.from(context);
		inflater.inflate(R.layout.list_item_story, this);
		
		this.initializeReferences();
	}
	
	/**
	 * Sets the {@link Story} this view should display.
	 * @param story {@link Story} to display.
	 */
	public void setStory(Story story) {
		Assert.assertTrue(story != null);
		
		this.setTitle(story.getTitle());
		this.showAsRead(story.isRead());
	}

	/**
	 * Initializes child references for this view.
	 */
	private void initializeReferences() {
		this._title = 
			(TextView) this.findViewById(R.id.StoryListItem_title);
	}
	
	/**
	 * Sets the title label of this view.
	 * @param title Title {@link CharSequence} to set.
	 */
	private void setTitle(CharSequence title) {
		this._title.setText(title);
	}
	
	/**
	 * Shows this view as read or unread.
	 * @param isRead <code>true</code> to show this view as read,
	 * 				 <code>false</code> to show as unread.
	 */
	private void showAsRead(boolean isRead) {
		Context context = this.getContext();
		if (isRead)
			this._title.setTextAppearance(context, R.style.TextAppearance_Story_Title_Read);
		else
			this._title.setTextAppearance(context, R.style.TextAppearance_Story_Title_Unread);
	}
	
}