/**
 * Copyright 2012 Scott Weeden-Moody
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.lillicoder.newsblurry.util;

/**
 * Utility class that provides some convenience methods for
 * processing arrays.
 */
public class ArrayUtils {

	/**
	 * Converts the given array of {@link Integer} to an array
	 * of int. If the given Integer array is empty, an empty int
	 * array will be returned. If the given Integer array is <code>null</code>,
	 * <code>null</code> will be returned.
	 * @param array {@link Integer} array to convert.
	 * @return int array converted from the given {@link Integer} array.
	 */
	public static int[] toPrimitive(Integer[] array) {
		// If given array is null, return null.
		if (array == null)
			return null;
		
		// If given array is empty, return empty int array.
		if (array.length == 0)
			return new int[0];
		
		// Step through each Integer and place the int value
		// into the proper position.
		int[] convertedArray = new int[array.length];
		for (int index = 0; index < array.length; index++)
			convertedArray[index] = array[index].intValue();
		
		return convertedArray;
	}
	
}